<?php

namespace Drupal\simple_xapi\Controller;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Controller\ControllerBase;
use Drupal\simple_xapi\SimpleXAPI;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for Simple xAPI routes.
 */
class RequestController extends ControllerBase {

  /**
   * The simple_xapi service.
   *
   * @var \Drupal\simple_xapi\SimpleXAPI
   */
  protected $simpleXAPI;

  /**
   * The controller constructor.
   *
   * @param \Drupal\simple_xapi\SimpleXAPI $simple_xapi
   *   The simple_xapi service.
   */
  public function __construct(SimpleXAPI $simple_xapi) {
    $this->simpleXAPI = $simple_xapi;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('simple_xapi')
    );
  }

  /**
   * Sends an xAPI request to and endpoint.
   *
   * Returns a json_encoded array with the response.
   *
   * @param string $action
   *   The LRS' API function to call.
   *   Possible values: statements, about.
   * @param array $data
   *   A valid xAPI JSON object that represents the data to send.
   * @param string $method
   *   The HTTP method to use for the request.
   *   Possible values: GET, POST, PUT, DELETE, HEAD.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   JsonResponse.
   */
  public function sendAjaxRequest($action, array $data, $method) {
    $response = $this->simpleXAPI->sendRequest($action, $data, $method);
    return new JsonResponse([
      'data' => Json::encode($response),
    ]);

  }

}
