<?php

namespace Drupal\simple_xapi\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\simple_xapi\SimpleXAPI;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * {@inheritdoc}
 */
class SimpleXapiAdminForm extends ConfigFormBase {

  /**
   * SimpleXAPI service.
   *
   * @var \Drupal\simple_xapi\SimpleXAPI
   */
  protected $simpleXAPI;

  /**
   * Constructs a SimpleXapiAdminForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config Factory.
   * @param \Drupal\simple_xapi\SimpleXAPI $simple_xapi
   *   SimpleXAPI service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, SimpleXAPI $simple_xapi) {
    parent::__construct($config_factory);
    $this->simpleXAPI = $simple_xapi;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('simple_xapi')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'simple_xapi_admin_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['simple_xapi.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('simple_xapi.settings');
    $form['api'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('API Settings'),
    ];

    $form['api']['connection'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Connection details'),
    ];

    $form['api']['connection']['description'] = [
      '#type' => 'item',
      '#markup' => $this->t('Provide the connection details for the remote system (usually a Learning Record System) where you want to store the xAPI statements.'),
    ];

    $form['api']['connection']['endpoint'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Endpoint'),
      '#description' => $this->t('The xAPI server endpoint. Example: https://example.com/trax/ws/xapi'),
      '#default_value' => $config->get('endpoint'),
      '#required' => TRUE,
    ];

    $form['api']['connection']['auth_user_key'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Username or shared key'),
      '#default_value' => $config->get('auth_user_key'),
    ];

    $form['api']['connection']['auth_password_key'] = [
      '#type' => 'key_select',
      '#title' => $this->t('Password or secret key'),
      '#default_value' => $config->get('auth_password_key'),
    ];

    $form['api']['error_logging_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log errors.'),
      '#default_value' => $config->get('error_logging_enabled'),
    ];

    $form['api']['debug_logging_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Log debug info.'),
      '#default_value' => $config->get('debug_logging_enabled'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('simple_xapi.settings');

    foreach ($form_state->getValues() as $key => $value) {
      $config->set($key, $value);
    }
    $config->save();
    parent::submitForm($form, $form_state);

    // Check connection with supplied details.
    $this->simpleXAPI->testConnection();
  }

}
