<?php

namespace Drupal\simple_xapi;

/**
 * Interface SimpleXAPIInterface.
 *
 * @package Drupal\simple_xapi
 */
interface SimpleXAPIInterface {

  /**
   * Accessed a uri.
   */
  const ACCESSED = "https://w3id.org/xapi/dod-isd/verbs/accessed";

  /**
   * Submitted answer to single question.
   */
  const ANSWERED = "http://adlnet.gov/expapi/verbs/answered";

  /**
   * Participated in (virtual) meeting/event, conference call, webinar, ...
   */
  const ATTENDED = "https://w3id.org/xapi/adb/verbs/attended";

  /**
   * Left a comment on a page/node/... or on another comment.
   */
  const COMMENTED = "http://adlnet.gov/expapi/verbs/commented";

  /**
   * Worked through a certain chapter or submitted all questions.
   */
  const COMPLETED = "http://adlnet.gov/expapi/verbs/completed";

  /**
   * Create a node or an entity.
   */
  const CREATED = "https://w3id.org/xapi/dod-isd/verbs/created";

  /**
   * Downloaded document, archive, ...
   */
  const DOWNLOADED = "http://id.tincanapi.com/verb/downloaded";

  /**
   * After completing assessment, user failed (or passed).
   */
  const FAILED = "http://adlnet.gov/expapi/verbs/failed";

  /**
   * After completing assessment, user passed (or failed).
   */
  const PASSED = "http://adlnet.gov/expapi/verbs/passed";

  /**
   * Received diploma / certificate / badge / ...
   */
  const RECEIVED = "https://w3id.org/xapi/dod-isd/verbs/received";

  /**
   * Submitted assessment and received a score.
   */
  const SCORED = "http://adlnet.gov/expapi/verbs/scored";

  /**
   * Started a course, filling in assessment, playing Video/audio, others.
   */
  const STARTED = "https://w3id.org/xapi/dod-isd/verbs/started";

  /**
   * Define 'accessed' over 'viewed'.
   */
  const VIEWED = "http://id.tincanapi.com/verb/viewed";

  /**
   * Sends an xAPI request to and endpoint.
   *
   * @param string $action
   *   The LRS' API function to call.
   *   Possible values: statements, about.
   * @param array $data
   *   A valid xAPI JSON object that represents the data to send.
   * @param string $method
   *   The HTTP method to use for the request.
   *   Possible values: GET, POST, HEAD.
   *
   * @return array
   *   Http response.
   */
  public function sendRequest($action, array $data, $method);

  /**
   * Test XAPI connection.
   *
   * @return array
   *   Http response.
   */
  public function testConnection();

}
